import string
import unicodedata
from urllib.parse import ParseResult
from urllib.parse import quote_plus
from urllib.parse import urlparse


def clean(s: str) -> str:
    """
    Given a string, remove all invalid chars and truncate the string if it's too long.
    """
    # keep only valid ascii chars
    cleaned: str = unicodedata.normalize("NFKD", s).encode("ASCII", "ignore").decode()

    # keep only whitelisted chars
    whitelist: str = "%s%s%s%s" % (
        string.ascii_letters,
        string.digits,
        string.punctuation,
        " ",
    )
    cleaned_and_whitelisted: str = "".join(c for c in cleaned if c in whitelist)
    return cleaned_and_whitelisted[:255]


def clean_url(url: str) -> str:
    """
    Escape any invalid characters in the URL query and fragment.
    """
    parsed: ParseResult = urlparse(url=url)
    parsed._replace(
        query=quote_plus(parsed.query), fragment=quote_plus(parsed.fragment)
    )
    return parsed.geturl()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pretty_history']

package_data = \
{'': ['*']}

install_requires = \
['appdirs>=1.4.4,<2.0.0', 'browserexport>=0.2.10,<0.3.0']

entry_points = \
{'console_scripts': ['prettyhist = pretty_history.main:main']}

setup_kwargs = {
    'name': 'pretty-history',
    'version': '2.0.1',
    'description': 'Generate a pretty view of your browser history from a JSON export',
    'long_description': '# pretty-history\n\n[![PyTest](https://github.com/apatel762/pretty-history/actions/workflows/pytest.yml/badge.svg)](https://github.com/apatel762/pretty-history/actions/workflows/pytest.yml) [![PyPi version](https://img.shields.io/pypi/v/browserexport.svg)](https://pypi.python.org/pypi/browserexport) [![Python 3.7|3.8|3.9](https://img.shields.io/pypi/pyversions/browserexport.svg)](https://pypi.python.org/pypi/browserexport) [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)\n\nThe `pretty-history` app is a simple Python script that can be run via the command-line, and will generate Markdown files summarising your browser history.\n\n## Installation\n\nInstall from the PyPi repository using `pip`:\n\n```\npip install pretty-history\n```\n\n## Usage\n\nAfter installing the app, run:\n\n```\nprettyhist --help\n```\n\nTo see some instructions for how to use it.\n\n### Example\n\nPretty-format browsing history from Firefox:\n\n```bash\nprettyhist -b firefox\n```\n\nPretty-format browsing history from Firefox, merging with data from Brave Browser:\n\n```bash\nbrowserexport save --browser brave --to .\nbrowserexport merge --json ./*.sqlite > ./history.json\n\nprettyhist -b firefox -f ./history.json\n```\n\n## References\n\n1. [seanbreckenridge/browserexport](https://github.com/seanbreckenridge/browserexport)\n',
    'author': 'Arjun Patel',
    'author_email': 'relay-git-1LKQ1GqLp0Nn4@aspatel.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/apatel762/pretty-history',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
